==> drd-8.x-3.9.tar.gz: drd/modules/drd_pi_pantheon/src/Entity/Account.php <==
<?php

namespace Drupal\drd_pi_pantheon\Entity;

use Drupal\drd_pi\DrdPiAccount;
use Drupal\drd_pi\DrdPiCore;
use Drupal\drd_pi\DrdPiDomain;
use Drupal\drd_pi\DrdPiHost;
use Drupal\drd_pi_pantheon\PiDomain;

/**
 * Defines the Pantheon Account entity.
 *
 * @ConfigEntityType(
 *   id = "pantheon_account",
 *   label = @Translation("Pantheon Account"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\drd_pi_pantheon\Entity\Builder\AccountListBuilder",
 *     "form" = {
 *       "add" = "Drupal\drd_pi_pantheon\Entity\Form\AccountForm",
 *       "edit" = "Drupal\drd_pi_pantheon\Entity\Form\AccountForm",
 *       "delete" = "Drupal\drd_pi_pantheon\Entity\Form\AccountDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\drd_pi_pantheon\Entity\Builder\AccountHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "pantheon_account",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "canonical" = "/drd/settings/pantheon/accounts/{pantheon_account}",
 *     "add-form" = "/drd/settings/pantheon/accounts/add",
 *     "edit-form" = "/drd/settings/pantheon/accounts/{pantheon_account}/edit",
 *     "delete-form" = "/drd/settings/pantheon/accounts/{pantheon_account}/delete",
 *     "collection" = "/drd/settings/pantheon/accounts"
 *   }
 * )
 */
class Account extends DrdPiAccount implements AccountInterface {

  private $authenticated = FALSE;

  /** @var DrdPiHost[] */
  private $hosts;

  /** @var DrdPiCore[] */
  private $cores;

  /** @var DrdPiDomain[] */
  private $domains;

  /** @var \Drupal\Core\Config\ImmutableConfig */
  protected $config;

  /**
   * The Machine Token.
   *
   * @var string
   */
  protected $machine_token;

  /**
   * @inheritDoc
   */
  public function __construct(array $values, $entity_type) {
    parent::__construct($values, $entity_type);
    $this->config = \Drupal::config('drd_pi_pantheon.settings');
  }

  /**
   * @inheritDoc
   */
  public function getPlatformName() {
    return 'Pantheon';
  }

  /**
   * @inheritDoc
   */
  public function getMachineToken() {
    return $this->machine_token;
  }

  /**
   * @inheritDoc
   */
  public function getPlatformHosts() {
    $this->hosts = [];

    if ($result = $this->shell('site:list')) {
      foreach ($result as $item) {
        if ($item->frozen == 'false' && in_array($item->framework, ['drupal', 'drupal8'])) {
          $name = implode(' ', [
            $this->getPlatformName(),
            $this->label(),
            $item->name,
          ]);
          $this->hosts[$item->id] = new DrdPiHost($name, $this->entityTypeId, $this->id(), $item->id);
        }
      }
    }
    return $this->hosts;
  }

  /**
   * @inheritDoc
   */
  public function getPlatformCores($host) {
    $this->cores = [];

    if ($result = $this->shell('env:list ' . $host->id())) {
      foreach ($result as $item) {
        if ($item->initialized == 'true') {
          $core = new DrdPiCore($item->id, $this->entityTypeId, $this->id(), $item->id, $host);
          $domain = new PiDomain($item->id, $this->entityTypeId, $this->id(), $item->id, $core, $item->domain, $this);
          $core->addDomain($domain);
          $this->cores[$item->id] = $core;
        }
      }
    }
    return $this->cores;
  }

  /**
   * @inheritDoc
   */
  public function getPlatformDomains($core) {
    $this->domains = [];

    if (isset($this->cores[$core->id()])) {
      $this->domains = $this->cores[$core->id()]->getDomains();
    }
    return $this->domains;
  }

  /**
   * @inheritDoc
   */
  public function shell($cmd, $subcmd = '', $collect = TRUE) {
    $this->auth();
    return $this->shellInternal($cmd, $subcmd, $collect);
  }

  private function shellInternal($cmd, $subcmd, $collect) {
    $cmd = $this->config->get('terminus') . ' --no-interaction --yes ' . $cmd;
    if ($collect) {
      $cmd .= ' --format=json';
    }
    if (!empty($subcmd)) {
      $cmd .= ' -- ' . $subcmd;
    }
    if (empty(parent::shell($cmd))) {
      return $collect ? json_decode($this->lastShellOutput) : TRUE;
    }
    \Drupal::service('drd.logging')->log('critical', $this->lastShellOutput);
    return FALSE;
  }

  private function auth() {
    if ($this->authenticated) {
      return;
    }
    $this->authenticated = $this->shellInternal('auth:login --machine-token=' . $this->getMachineToken(), '', FALSE);
  }

}

==> drd-8.x-3.10.tar.gz: drd/modules/drd_pi_pantheon/src/Entity/Account.php <==
<?php

namespace Drupal\drd_pi_pantheon\Entity;

use Drupal\drd_pi\DrdPiAccount;
use Drupal\drd_pi\DrdPiCore;
use Drupal\drd_pi\DrdPiDomain;
use Drupal\drd_pi\DrdPiHost;

/**
 * Defines the Pantheon Account entity.
 *
 * @ConfigEntityType(
 *   id = "pantheon_account",
 *   label = @Translation("Pantheon Account"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\drd_pi\DrdPiAccountListBuilder",
 *     "form" = {
 *       "add" = "Drupal\drd_pi_pantheon\Entity\AccountForm",
 *       "edit" = "Drupal\drd_pi_pantheon\Entity\AccountForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "pantheon_account",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "canonical" = "/drd/settings/pantheon/accounts/{pantheon_account}",
 *     "add-form" = "/drd/settings/pantheon/accounts/add",
 *     "edit-form" = "/drd/settings/pantheon/accounts/{pantheon_account}/edit",
 *     "delete-form" = "/drd/settings/pantheon/accounts/{pantheon_account}/delete",
 *     "collection" = "/drd/settings/pantheon/accounts"
 *   }
 * )
 */
class Account extends DrdPiAccount implements AccountInterface {

  private $authenticated = FALSE;

  /** @var string */
  protected $machine_token;

  /**
   * @inheritdoc
   */
  public static function getConfigName() {
    return 'drd_pi_pantheon.settings';
  }

  /**
   * @inheritDoc
   */
  public function getPlatformName() {
    return 'Pantheon';
  }

  /**
   * @inheritDoc
   */
  public function getMachineToken() {
    return $this->machine_token;
  }

  /**
   * @inheritDoc
   */
  public function getPlatformHosts() {
    $this->hosts = [];

    if ($result = $this->shell('site:list')) {
      foreach ($result as $item) {
        if ($item->frozen == 'false' && in_array($item->framework, ['drupal', 'drupal8'])) {
          $name = implode(' ', [
            $this->getPlatformName(),
            $this->label(),
            $item->name,
          ]);
          $this->hosts[$item->id] = new DrdPiHost($this, $name, $item->id);
        }
      }
    }
    return $this->hosts;
  }

  /**
   * @inheritDoc
   */
  public function getPlatformCores($host) {
    $this->cores = [];

    if ($result = $this->shell('env:list ' . $host->id())) {
      foreach ($result as $item) {
        if ($item->initialized == 'true') {
          $core = new DrdPiCore($this, $item->id, $item->id);
          $core->setHost($host);
          $domain = new DrdPiDomain($this, $item->id, $item->id);
          $domain->setDetails($core, $item->domain);
          $core->addDomain($domain);
          $this->cores[$item->id] = $core;
        }
      }
    }
    return $this->cores;
  }

  /**
   * @inheritdoc
   */
  public function drush($domain, $drushcmd) {
    $cmd = 'remote:drush ' . $domain->host()->id() . '.' . $domain->id();
    return $this->shell($cmd, $drushcmd, FALSE);
  }

  /**
   * @inheritDoc
   */
  public function shell($cmd, $subcmd = '', $collect = TRUE) {
    $this->auth();
    return $this->shellInternal($cmd, $subcmd, $collect);
  }

  private function shellInternal($cmd, $subcmd, $collect) {
    $cmd = $this->config->get('terminus') . ' --no-interaction --yes ' . $cmd;
    if ($collect) {
      $cmd .= ' --format=json';
    }
    if (!empty($subcmd)) {
      $cmd .= ' -- --strict=0 --no-interaction --yes ' . $subcmd;
    }
    if (empty(parent::shell($cmd))) {
      return $collect ? json_decode($this->lastShellOutput) : TRUE;
    }
    \Drupal::service('drd.logging')->log('critical', $this->lastShellOutput);
    return FALSE;
  }

  private function auth() {
    if ($this->authenticated) {
      return;
    }
    $this->authenticated = $this->shellInternal('auth:login --machine-token=' . $this->getMachineToken(), '', FALSE);
  }

}
